Attribute VB_Name = "FieldValidations"
' ************************************************
' Routines for field validation.
' ************************************************
Option Explicit

Const KEY_MIN = 32   ' Smallest visible character.
Const KEY_MAX = 126  ' Largest visible character.
Const KEY_DOT = 46   ' Period.
Const KEY_PLUS = 43  ' Plus.
Const KEY_MINUS = 45 ' Minus.
Const KEY_CTL_V = 22 ' Control-V.
Const KEY_CTL_C = 3  ' Control-C.
Const KEY_CTL_X = 24 ' Control-X.

' In KeyDown events the delete key generates
' keycode 46. This key does not generate any code
' in KeyPress events and 46 represents the period
' in KeyPress events. We use KEY_DELETE as a
' phoney ASCII code for passing the delete
' character into routines that manipulate KeyPress
' events.
Const KEY_DELETE = 1 ' Phoney ASCII delete value.

' ************************************************
' See if the required field is blank. If so, beep,
' present a message box asking the user to fill in
' the field, move the field's container to the top
' of the Z-order, set focus to the field, and
' return true. Otherwise return false.
'
' Skip non-editable fields.
' ************************************************
Public Function BlankRequired(ctl As Control, msg As String) As Boolean
    If ctl.Locked Or ctl.Text <> "" Then
        BlankRequired = False
    Else
        PresentMessage ctl, msg, vbOKOnly, "Value Required"
        BlankRequired = True
    End If
End Function

' ************************************************
' Return the value this text box will have if the
' character is accepted.
'
' This is a simple function and is not guaranteed
' to handle all kinds of control sequences. In
' particular, ^Z is quite complicated. Presumably
' of the text was legal before, ^Z will restore it
' to a legal value.
' ************************************************
Public Function NewValue(ctl As TextBox, key As Integer) As String
Dim txt As String
Dim start As Integer
Dim length As Integer
Dim length3 As Integer
Dim txt1 As String
Dim txt2 As String
Dim txt3 As String

    txt = ctl.Text
        
    If (key < KEY_MIN Or key > KEY_MAX) And _
        key <> KEY_CTL_V And _
        key <> KEY_CTL_X And _
        key <> KEY_DELETE And _
        key <> vbKeyReturn And _
        key <> vbKeyBack _
    Then
        ' It's an unknown non-visible key like ^C.
        ' Assume it will not change the text.
        NewValue = txt
        Exit Function
    End If
        
    start = ctl.SelStart
    length = ctl.SelLength
    
    ' Calculate the first part of the new text.
    If start < 1 Then
        txt1 = ""
    Else
        txt1 = Left$(txt, start)
    End If

    ' Calculate the third part of the new text.
    length3 = Len(txt) - start - length
    If length3 < 1 Then
        txt3 = ""
    Else
        txt3 = Right$(txt, length3)
    End If
    
    ' Calculate the middle part of the new text.
    If key = KEY_CTL_V Then
        txt2 = Clipboard.GetText()
    ElseIf key = KEY_CTL_X Then
        ' Delete the selected text.
        txt2 = ""
    ElseIf key = KEY_DELETE Then
        If length = 0 And txt3 <> "" Then
            ' Delete the character after the
            ' insertion point.
            txt3 = Right$(txt3, Len(txt3) - 1)
        Else
            txt2 = ""
        End If
    ElseIf key = vbKeyBack Then
        If length = 0 And txt1 <> "" Then
            ' Delete the character before the
            ' insertion point.
            txt1 = Left$(txt1, Len(txt1) - 1)
        Else
            txt2 = ""
        End If
    Else
        ' It's a return or printable character.
        txt2 = Chr$(key)
    End If
    
    NewValue = txt1 & txt2 & txt3
End Function

' ************************************************
' Beep, highlight the field, move the field's
' container to the top of the Z-order, present the
' indicated message, unhighlight the field, and
' set focus to the field.
' ************************************************
Public Sub PresentMessage(ctl As Control, msg As String, buttons As Long, msg_title As String)
Dim prev_tab As Integer
Dim fg_color As Long
Dim bg_color As Long

    ' Move the container to the top.
    prev_tab = EmployeeForm.InfoTab.Tab
    EmployeeForm.InfoTab.Tab = ctl.Container.Index
    EmployeeForm.InfoTab_Click prev_tab

    Beep
    
    ' Remember the original colors.
    fg_color = ctl.ForeColor
    bg_color = ctl.BackColor
    
    ' Highlight the field.
    ctl.ForeColor = bg_color
    ctl.BackColor = fg_color
    
    ' Present the message.
    MsgBox msg, buttons, msg_title
        
    ' Restore the colors.
    ctl.ForeColor = fg_color
    ctl.BackColor = bg_color
    
    ' Set the focus.
    ctl.SetFocus
End Sub

' ************************************************
' Return false if the string is a valid monetary
' value. Otherwise tell the user and return true.
'
' If the value does not have two digits after a
' decimal point, add them.
' ************************************************
Public Function ValidateMoney(ctl As TextBox, msg As String) As Boolean
Dim txt As String
Dim bad As Boolean
Dim pos As Integer

    ' Skip non-editable fields.
    If ctl.Locked Then
        ValidateMoney = False
        Exit Function
    End If
    
    ' Assume the field is valid.
    bad = False

    txt = ctl.Text
    If txt = "" Then
        ' Allow "".
    ElseIf Not IsNumeric(txt) Then
        bad = True
    Else
        pos = InStr(txt, ".")
        If pos = 0 Then
            ' Not found. Add ".00"
            ctl.Text = ctl.Text & ".00"
        ElseIf pos < Len(txt) - 2 Then
            ' Too many digits after the decimal.
            bad = True
        ElseIf pos = Len(txt) - 1 Then
            ctl.Text = ctl.Text & "0"
        ElseIf pos = Len(txt) Then
            ctl.Text = ctl.Text & "00"
        End If
    End If
    
    If bad Then _
        PresentMessage ctl, msg, vbOKOnly, _
            "Invalid Monetary Format"
    
    ValidateMoney = bad
End Function

' ************************************************
' Return true if the string has a valid format.
' Otherwise return false, beep, and make the
' foreground color red.
' ************************************************
Public Function ValidateName(ctl As TextBox) As Boolean
Dim txt As String
Dim color As Long

    ' Skip non-editable fields.
    If ctl.Locked Then
        ValidateName = False
        Exit Function
    End If
    
    txt = ctl.Text
    If ValidName(txt) Then
        color = vbBlack
    Else
        color = vbRed
    End If
    
    If ctl.ForeColor <> color Then
        If color = vbRed Then Beep
        ctl.ForeColor = color
    End If
    
    ValidateName = (color = vbBlack)
End Function

' ************************************************
' Return true if the string has a valid format.
' Otherwise return false, beep, and make the
' foreground color red.
' ************************************************
Public Function ValidateDigits(ctl As TextBox, msg As String) As Boolean
Dim txt As String

    ' Skip non-editable fields.
    If ctl.Locked Then
        ValidateDigits = False
        Exit Function
    End If
    
    txt = ctl.Text
    If ValidDigits(txt) Then
        ValidateDigits = False
    Else
        PresentMessage ctl, msg, vbOKOnly, _
            "Invalid Digit Format"
        ValidateDigits = True
    End If
End Function


' ************************************************
' Return false if the string is a valid date
' value. Otherwise tell the user and return true.
' ************************************************
Public Function ValidateDate(ctl As TextBox, msg As String) As Boolean
Dim txt As String
Dim bad As Boolean
Dim pos1 As Integer
Dim pos2 As Integer

    ' Skip non-editable fields.
    If ctl.Locked Then
        ValidateDate = False
        Exit Function
    End If
    
    txt = ctl.Text
    
    ' Assume the date is good.
    bad = False
    
    If txt = "" Then
        bad = False
    ElseIf Not IsDate(txt) Then
        bad = True
    Else
        ' See if we have a month, day, and year.
        pos1 = InStr(txt, "/")
        pos2 = InStr(pos1 + 1, txt, "/")
        bad = (pos2 = 0 Or _
               pos2 = pos1 + 1 Or _
               pos2 <> Len(txt) - 2)
    End If
    If bad Then
        PresentMessage ctl, msg, vbOKOnly, _
            "Invalid Date Format"
        ValidateDate = True
    Else
        ValidateDate = False
    End If
End Function

' ************************************************
' Return false if the string is a valid Zip Code
' value. Otherwise tell the user and return true.
' ************************************************
Public Function ValidateZip(ctl As TextBox, msg As String) As Boolean
Dim txt As String
Dim bad As Boolean
Dim length As Integer

    ' Skip non-editable fields.
    If ctl.Locked Then
        ValidateZip = False
        Exit Function
    End If
    
    txt = ctl.Text
    
    If Not ValidZip(txt) Then
        bad = True
    Else
        ' Make sure we have 5 or 10 characters.
        length = Len(txt)
        bad = (length <> 0 And length <> 5 And length <> 10)
    End If
    
    If bad Then
        PresentMessage ctl, msg, vbOKOnly, _
            "Invalid Zip Code Format"
        ValidateZip = True
    Else
        ValidateZip = False
    End If
End Function
' ************************************************
' Return false if the string is a valid phone
' number. Otherwise tell the user and return true.
' ************************************************
Public Function ValidatePhone(ctl As TextBox, msg As String) As Boolean
Dim txt As String
Dim bad As Boolean
Dim length As Integer

    ' Skip non-editable fields.
    If ctl.Locked Then
        ValidatePhone = False
        Exit Function
    End If
    
    txt = ctl.Text
    
    If Not ValidPhone(txt) Then
        bad = True
    Else
        ' Make sure we have 0, 8, or 12 characters.
        length = Len(txt)
        bad = (length <> 0 And length <> 8 And length <> 12)
    End If
    
    If bad Then
        PresentMessage ctl, msg, vbOKOnly, _
            "Invalid Phone Number Format"
        ValidatePhone = True
    Else
        ValidatePhone = False
    End If
End Function
' ************************************************
' Return false if the string is a Social Security
' number. Otherwise tell the user and return true.
' ************************************************
Public Function ValidateSSN(ctl As TextBox, msg As String) As Boolean
Dim txt As String
Dim bad As Boolean
Dim length As Integer

    ' Skip non-editable fields.
    If ctl.Locked Then
        ValidateSSN = False
        Exit Function
    End If
    
    txt = ctl.Text
    
    If Not ValidSSN(txt) Then
        bad = True
    Else
        ' Make sure we have 0 or 11 characters.
        length = Len(txt)
        bad = (length <> 0 And length <> 11)
    End If
    
    If bad Then
        PresentMessage ctl, msg, vbOKOnly, _
            "Invalid Social Security Number Format"
        ValidateSSN = True
    Else
        ValidateSSN = False
    End If
End Function

' ************************************************
' Return true if the string has a valid monetary
' format.
' ************************************************
Public Function ValidMoney(txt As String) As Boolean
Dim pos As Integer

    If txt = "" Then
        ' Always allow the empty string.
        ValidMoney = True
    ElseIf Not IsNumeric(txt) Then
        ValidMoney = False
    ElseIf InStr(txt, Chr(vbKeyReturn)) <> 0 Then
        ' Do not allow imbedded carriage returns.
        ValidMoney = False
    Else
        pos = InStr(txt, ".")
        If pos > 0 And pos < Len(txt) - 2 Then
            ' Too many digits after the decimal.
            ValidMoney = False
        Else
            ValidMoney = True
        End If
    End If
End Function

' ************************************************
' Return true if the string contains only letters,
' spaces, and periods as in "John Q. Public".
' This still allows things like "QQ   QQ..." but
' it should prevent most simple mistakes.
' ************************************************
Public Function ValidName(txt As String) As Boolean
Dim i As Integer
Dim ch As String

    For i = 1 To Len(txt)
        ch = Mid$(txt, i, 1)
        If (ch < "a" Or ch > "z") And _
           (ch < "A" Or ch > "Z") And _
           ch <> " " And _
           ch <> "." _
        Then
            ValidName = False
            Exit Function
        End If
    Next i
    ValidName = True
End Function
' ************************************************
' Return true if the string contains only digits.
' ************************************************
Public Function ValidDigits(txt As String) As Boolean
Dim i As Integer
Dim ch As String

    For i = 1 To Len(txt)
        ch = Mid$(txt, i, 1)
        If (ch < "0" Or ch > "9") Then
            ValidDigits = False
            Exit Function
        End If
    Next i
    ValidDigits = True
End Function

' ************************************************
' Return true if the string is the beginning of a
' valid date of the form M[M]/D[D]/YY.
'
' This simple funciton just checks that the text
' contains a prefix of one or two digits, a slash,
' one or two digits, a slash, and one or two
' digits.
' ************************************************
Public Function ValidDate(txt As String) As Boolean
Dim length As Integer
Dim i As Integer
Dim str As String
Dim pos As Integer
Dim newpos As Integer
Dim num As Integer
    
    ' We exit early if we fail.
    ValidDate = False
    
    ' Fail if the string is too long.
    length = Len(txt)
    If length > 10 Then Exit Function
    
    ' Always allow "".
    If length < 1 Then
        ValidDate = True
        Exit Function
    End If
    
    ' Read the month.
    pos = InStr(txt, "/")
    ' Fail if there are no digits before the "/".
    If pos = 1 Then Exit Function
    If pos = 0 Then pos = length + 1
    str = Left$(txt, pos - 1)
    ' Fail if there are non-digits.
    If Not ValidDigits(str) Then Exit Function
    num = CInt(str)
    ' Fail if the month is too big or small.
    If num < 1 Or num > 12 Then Exit Function
    ' If the string ends now, succeed.
    If pos >= length Then
        ValidDate = True
        Exit Function
    End If
    
    ' Read the day.
    newpos = InStr(pos + 1, txt, "/")
    If newpos = 0 Then newpos = length + 1
    ' Fail if we have "//".
    If newpos <= pos + 1 Then Exit Function
    str = Mid$(txt, pos + 1, newpos - pos - 1)
    ' Fail if there are non-digits.
    If Not ValidDigits(str) Then Exit Function
    num = CInt(str)
    ' Fail if the day is too big or small.
    If num < 1 Or num > 31 Then Exit Function
    ' If the string ends now, succeed.
    If newpos >= length Then
        ValidDate = True
        Exit Function
    End If
    pos = newpos
    
    ' Read the year.
    newpos = pos + 5
    If newpos > length Then newpos = length + 1
    str = Mid$(txt, pos + 1, newpos - pos - 1)
    ' Fail if there are non-digits.
    If Not ValidDigits(str) Then Exit Function
    num = CInt(str)
    
    ' If the string ends now, succeed. Otherwise
    ' we fail as in "3/3/12345".
    ValidDate = (newpos = length + 1)
End Function

' ************************************************
' Return true if the string is the beginning of a
' valid Zip Code of the form ZZZZZ-ZZZZ.
' ************************************************
Public Function ValidZip(txt As String) As Boolean
Dim length As Integer
Dim i As Integer
Dim ch As String

    ' Assume we will succeed.
    ValidZip = True
    
    length = Len(txt)
    
    ' Always allow "".
    If length < 1 Then Exit Function
    
    ' Fail if the string is too long.
    If length > 10 Then
        ValidZip = False
        Exit Function
    End If
    
    ' Read the first five digits.
    For i = 1 To 5
        If i > length Then Exit Function
        ch = Mid$(txt, i, 1)
        If (ch < "0" Or ch > "9") Then
            ValidZip = False
            Exit Function
        End If
    Next i
    
    ' Read the dash.
    If length < 6 Then Exit Function
    If Mid$(txt, 6, 1) <> "-" Then
        ValidZip = False
        Exit Function
    End If
    
    ' Read the Zip+4 digits.
    For i = 7 To 10
        If i > length Then Exit Function
        ch = Mid$(txt, i, 1)
        If (ch < "0" Or ch > "9") Then
            ValidZip = False
            Exit Function
        End If
    Next i
End Function
' ************************************************
' Return true if the string is the beginning of a
' valid phone number of the form 111-111-1111 or
' 111-1111.
' ************************************************
Public Function ValidPhone(txt As String) As Boolean
Dim length As Integer
Dim i As Integer
Dim ch As String

    ' Assume we will succeed.
    ValidPhone = True
    
    length = Len(txt)
    
    ' Always allow "".
    If length < 1 Then Exit Function
    
    ' Fail if the string is too long.
    If length > 12 Then
        ValidPhone = False
        Exit Function
    End If
    
    ' Read the first three digits.
    For i = 1 To 3
        If i > length Then Exit Function
        ch = Mid$(txt, i, 1)
        If (ch < "0" Or ch > "9") Then
            ValidPhone = False
            Exit Function
        End If
    Next i
    
    ' Read the first dash.
    If length < 4 Then Exit Function
    If Mid$(txt, 4, 1) <> "-" Then
        ValidPhone = False
        Exit Function
    End If
    
    ' Read the next 3 digits.
    For i = 5 To 7
        If i > length Then Exit Function
        ch = Mid$(txt, i, 1)
        If (ch < "0" Or ch > "9") Then
            ValidPhone = False
            Exit Function
        End If
    Next i
    
    ' If the next character is a dash, we have a
    ' 12 character phone number. Otherwise it's
    ' a 7 character phone number.
    If length < 8 Then Exit Function
    ch = Mid$(txt, 8, 1)
    If ch = "-" Then
        ' Read the last 4 digits.
        For i = 9 To 12
            If i > length Then Exit Function
            ch = Mid$(txt, i, 1)
            If (ch < "0" Or ch > "9") Then
                ValidPhone = False
                Exit Function
            End If
        Next i
    Else
        If ch < "0" Or ch > "9" Or length > 8 Then
            ValidPhone = False
            Exit Function
        End If
    End If
End Function
' ************************************************
' Return true if the string is the beginning of a
' valid Social Security number of the form
' 111-11-1111.
' ************************************************
Public Function ValidSSN(txt As String) As Boolean
Dim length As Integer
Dim i As Integer
Dim ch As String

    ' Assume we will succeed.
    ValidSSN = True
    
    length = Len(txt)
    
    ' Always allow "".
    If length < 1 Then Exit Function
    
    ' Fail if the string is too long.
    If length > 11 Then
        ValidSSN = False
        Exit Function
    End If
    
    ' Read the first three digits.
    For i = 1 To 3
        If i > length Then Exit Function
        ch = Mid$(txt, i, 1)
        If (ch < "0" Or ch > "9") Then
            ValidSSN = False
            Exit Function
        End If
    Next i
    
    ' Read the first dash.
    If length < 4 Then Exit Function
    If Mid$(txt, 4, 1) <> "-" Then
        ValidSSN = False
        Exit Function
    End If
    
    ' Read the middle 2 digits.
    For i = 5 To 6
        If i > length Then Exit Function
        ch = Mid$(txt, i, 1)
        If (ch < "0" Or ch > "9") Then
            ValidSSN = False
            Exit Function
        End If
    Next i
    
    ' Read the second dash.
    If length < 7 Then Exit Function
    If Mid$(txt, 7, 1) <> "-" Then
        ValidSSN = False
        Exit Function
    End If
    
    ' Read the last 4 digits.
    For i = 8 To 11
        If i > length Then Exit Function
        ch = Mid$(txt, i, 1)
        If (ch < "0" Or ch > "9") Then
            ValidSSN = False
            Exit Function
        End If
    Next i
End Function

' ************************************************
' See if the character is allowed. If not, beep
' and set the character to 0 to reject it.
' ************************************************
Public Sub ValidateMoney_KeyDown(ctl As TextBox, key As Integer)
Dim newkey As Integer

    ' Only bother for vbKeyDelete. All others are
    ' handled in the KeyPress event handler.
    If key = vbKeyDelete Then
        newkey = KEY_DELETE
        ValidateMoney_KeyPress ctl, newkey
        
        ' If the routine rejected newkey, reject
        ' the original key.
        If newkey = 0 Then key = 0
    End If
End Sub
' ************************************************
' See if the character is allowed. If not, beep
' and set the character to 0 to reject it.
' ************************************************
Public Sub ValidateDate_KeyDown(ctl As TextBox, key As Integer)
Dim newkey As Integer

    ' Only bother for vbKeyDelete. All others are
    ' handled in the KeyPress event handler.
    If key = vbKeyDelete Then
        newkey = KEY_DELETE
        ValidateDate_KeyPress ctl, newkey
        
        ' If the routine rejected newkey, reject
        ' the original key.
        If newkey = 0 Then key = 0
    End If
End Sub

' ************************************************
' See if the character is allowed. If not, beep
' and set the character to 0 to reject it.
' ************************************************
Public Sub ValidateZip_KeyDown(ctl As TextBox, key As Integer)
Dim newkey As Integer

    ' Only bother for vbKeyDelete. All others are
    ' handled in the KeyPress event handler.
    If key = vbKeyDelete Then
        newkey = KEY_DELETE
        ValidateZip_KeyPress ctl, newkey
        
        ' If the routine rejected newkey, reject
        ' the original key.
        If newkey = 0 Then key = 0
    End If
End Sub
' ************************************************
' See if the character is allowed. If not, beep
' and set the character to 0 to reject it.
' ************************************************
Public Sub ValidatePhone_KeyDown(ctl As TextBox, key As Integer)
Dim newkey As Integer

    ' Only bother for vbKeyDelete. All others are
    ' handled in the KeyPress event handler.
    If key = vbKeyDelete Then
        newkey = KEY_DELETE
        ValidatePhone_KeyPress ctl, newkey
        
        ' If the routine rejected newkey, reject
        ' the original key.
        If newkey = 0 Then key = 0
    End If
End Sub
' ************************************************
' See if the character is allowed. If not, beep
' and set the character to 0 to reject it.
' ************************************************
Public Sub ValidateSSN_KeyDown(ctl As TextBox, key As Integer)
Dim newkey As Integer

    ' Only bother for vbKeyDelete. All others are
    ' handled in the KeyPress event handler.
    If key = vbKeyDelete Then
        newkey = KEY_DELETE
        ValidateSSN_KeyPress ctl, newkey
        
        ' If the routine rejected newkey, reject
        ' the original key.
        If newkey = 0 Then key = 0
    End If
End Sub

' ************************************************
' See if the character is allowed. If not, beep
' and set the character to 0 to reject it.
' ************************************************
Public Sub ValidateName_KeyDown(ctl As TextBox, key As Integer)
Dim newkey As Integer

    ' Only bother for vbKeyDelete. All others are
    ' handled in the KeyPress event handler.
    If key = vbKeyDelete Then
        newkey = KEY_DELETE
        ValidateName_KeyPress ctl, newkey
        
        ' If the routine rejected newkey, reject
        ' the original key.
        If newkey = 0 Then key = 0
    End If
End Sub
' ************************************************
' See if the character is allowed. If not, beep
' and set the character to 0 to reject it.
' ************************************************
Public Sub ValidateDigits_KeyDown(ctl As TextBox, key As Integer)
Dim newkey As Integer

    ' Only bother for vbKeyDelete. All others are
    ' handled in the KeyPress event handler.
    If key = vbKeyDelete Then
        newkey = KEY_DELETE
        ValidateDigits_KeyPress ctl, newkey
        
        ' If the routine rejected newkey, reject
        ' the original key.
        If newkey = 0 Then key = 0
    End If
End Sub



' ************************************************
' See if the character is allowed. If not, beep
' and set the character to 0 to reject it.
' ************************************************
Public Sub ValidateMoney_KeyPress(ctl As TextBox, key As Integer)
Dim txt As String

    txt = NewValue(ctl, key)
    If Not ValidMoney(txt) Then
        Beep
        key = 0
    End If
End Sub
' ************************************************
' See if the character is allowed. If not, beep
' and set the character to 0 to reject it.
' ************************************************
Public Sub ValidateDate_KeyPress(ctl As TextBox, key As Integer)
Dim txt As String

    txt = NewValue(ctl, key)
    If Not ValidDate(txt) Then
        Beep
        key = 0
    End If
End Sub
' ************************************************
' See if the character is allowed. If not, beep
' and set the character to 0 to reject it.
' ************************************************
Public Sub ValidateZip_KeyPress(ctl As TextBox, key As Integer)
Dim txt As String

    txt = NewValue(ctl, key)
    If Not ValidZip(txt) Then
        Beep
        key = 0
    End If
End Sub
' ************************************************
' See if the character is allowed. If not, beep
' and set the character to 0 to reject it.
' ************************************************
Public Sub ValidatePhone_KeyPress(ctl As TextBox, key As Integer)
Dim txt As String

    txt = NewValue(ctl, key)
    If Not ValidPhone(txt) Then
        Beep
        key = 0
    End If
End Sub
' ************************************************
' See if the character is allowed. If not, beep
' and set the character to 0 to reject it.
' ************************************************
Public Sub ValidateSSN_KeyPress(ctl As TextBox, key As Integer)
Dim txt As String

    txt = NewValue(ctl, key)
    If Not ValidSSN(txt) Then
        Beep
        key = 0
    End If
End Sub

' ************************************************
' See if the character is allowed. If not, beep
' and set the character to 0 to reject it.
' ************************************************
Public Sub ValidateName_KeyPress(ctl As TextBox, key As Integer)
Dim txt As String

    txt = NewValue(ctl, key)
    If Not ValidName(txt) Then
        Beep
        key = 0
    End If
End Sub
' ************************************************
' See if the character is allowed. If not, beep
' and set the character to 0 to reject it.
' ************************************************
Public Sub ValidateDigits_KeyPress(ctl As TextBox, key As Integer)
Dim txt As String

    txt = NewValue(ctl, key)
    If Not ValidDigits(txt) Then
        Beep
        key = 0
    End If
End Sub


